"""Configuration template utilities.

This module provides utilities for loading and processing configuration templates.
"""

from digital_employee_core.config_templates.loader import ConfigTemplateLoader

__all__ = ["ConfigTemplateLoader"]
