"""Constants module for digital employee core.

This module contains constant values used across the digital employee core package.

Authors:
    Immanuel Rhesa (immanuel.rhesa@gdplabs.id)

References:
    NONE
"""

from digital_employee_core.constants.models import (
    DEFAULT_MODEL_NAME,
    GPT_4_1_MODEL_NAME,
    GPT_5_1_HIGH_MODEL_NAME,
    GPT_5_1_LOW_MODEL_NAME,
    GPT_5_1_MEDIUM_MODEL_NAME,
    GPT_5_1_MODEL_NAME,
    GPT_5_LOW_MODEL_NAME,
    GPT_5_MINI_MODEL_NAME,
    GPT_5_MINIMAL_MODEL_NAME,
    GPT_5_MODEL_NAME,
)

__all__ = [
    "DEFAULT_MODEL_NAME",
    "GPT_4_1_MODEL_NAME",
    "GPT_5_MODEL_NAME",
    "GPT_5_MINIMAL_MODEL_NAME",
    "GPT_5_MINI_MODEL_NAME",
    "GPT_5_LOW_MODEL_NAME",
    "GPT_5_1_MODEL_NAME",
    "GPT_5_1_LOW_MODEL_NAME",
    "GPT_5_1_MEDIUM_MODEL_NAME",
    "GPT_5_1_HIGH_MODEL_NAME",
]
