"""Identity module for digital employee.

This module provides identity classes for digital employees.
"""

from digital_employee_core.identity.identity import (
    DigitalEmployeeIdentity,
    DigitalEmployeeJob,
    DigitalEmployeeSupervisor,
)

__all__ = [
    "DigitalEmployeeIdentity",
    "DigitalEmployeeJob",
    "DigitalEmployeeSupervisor",
]
